@@ -18,7 +18,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <gtk/gtkwidget.h>
+#include <gtk/gtk.h>
 #include <libspi/Accessibility.h>
 #include "bonobo_socket_atk_object.h"
 #include "bonobo_socket_atk_object_factory.h"
